type Tea::Syslogfacility = Enum[
  'kern',
  'user',
  'mail',
  'daemon',
  'auth',
  'lpr',
  'news',
  'uucp',
  'cron',
  'local0',
  'local1',
  'local2',
  'local3',
  'local4',
  'local5',
  'local6',
  'local7',
]
