# Use this file to instruct puppet-lint to ignore certain checks.
# For the complete list of checks and flags to disable them,
# refer to <http://puppet-lint.com/checks/>.

# Examples (uncomment before use):

# spacing, indentation and whitespace
#--no-2sp_soft_tabs-check
#--no-hard_tabs-check
#--no-trailing_whitespace-check
#--no-80chars-check
#--no-arrow_alignment-check

# comments
#--no-slash_comments-check
#--no-star_comments-check

# quoting
#--no-double_quoted_strings-check
#--no-variables_not_enclosed-check
#--no-only_variable_string-check
#--no-single_quote_string_with_variables-check
#--no-quoted_booleans-check
#--no-puppet_url_without_modules-check

# resources
#--no-unquoted_resource_title-check
#--no-ensure_first_param-check
#--no-ensure_not_symlink_target-check
#--no-file_mode-check
#--no-unquoted_file_mode-check
#--no-duplicate_params-check

# conditionals
#--no-selector_inside_resource-check
#--no-case_without_default-check

# classes
#--no-class_inherits_from_params_class-check
#--no-autoloader_layout-check
#--no-right_to_left_relationship-check
#--no-nested_classes_or_defines-check
#--no-inherits_across_namespaces-check
#--no-variable_scope-check
#--no-variable_contains_dash-check
#--no-parameter_order-check
#--no-names_containing_dash-check

# documentation
#--no-documentation-check

# nodes
#--no-unquoted_node_name-check

# For more controls please see http://puppet-lint.com/plugins/